@@ -1,5 +1,4 @@
-from urllib.parse import urlparse
-
+from six.moves.urllib import parse
 import requests
 from os import environ
 import re
@@ -8,8 +7,8 @@ from random import choice
 from python_anticaptcha import AnticaptchaClient, FunCaptchaTask
 
 api_key = environ["KEY"]
-site_key_pattern = 'data-pkey="(.+?)"'
-url = "https://www.funcaptcha.com/demo/"
+site_key_pattern = 'public_key: "(.+?)",'
+url = "https://client-demo.arkoselabs.com/solo-animals"
 client = AnticaptchaClient(api_key)
 session = requests.Session()
 
@@ -18,11 +17,11 @@ UA = (
     "(KHTML, like Gecko) Chrome/39.0.2171.95 Safari/537.36"
 )
 session.headers = {"User-Agent": UA}
-proxy_urls = environ["PROXY_URL"].split(",")
+proxy_url = environ["PROXY_URL"]
 
 
 def parse_url(url):
-    parsed = urlparse(url)
+    parsed = parse.urlparse(url)
     return dict(
         proxy_type=parsed.scheme,
         proxy_address=parsed.hostname,
@@ -37,11 +36,10 @@ def get_form_html():
 
 
 def get_token(form_html):
-    proxy_url = choice(proxy_urls)
     proxy = parse_url(proxy_url)
 
     site_key = re.search(site_key_pattern, form_html).group(1)
-    task = FunCaptchaTask(url, site_key, proxy=proxy, user_agent=UA)
+    task = FunCaptchaTask(url, site_key, user_agent=UA, **proxy)
     job = client.createTask(task)
     job.join(maximum_time=10 ** 4)
     return job.get_token_response()
@@ -53,4 +51,4 @@ def process():
 
 
 if __name__ == "__main__":
-    print(process())
+    print('Solved!' in process())
